@@ -24,25 +24,16 @@
 #include "spellerplugin_p.h"
 #include "hunspell.hxx"
 
-#ifndef HUNSPELL_MAIN_DICT_PATH
-#ifdef Q_OS_MAC
-#define HUNSPELL_MAIN_DICT_PATH "/System/Library/Spelling"
-#else
-#define HUNSPELL_MAIN_DICT_PATH "/usr/share/hunspell"
-#endif
-#endif
-
 class HunspellDict : public Sonnet::SpellerPlugin
 {
 public:
     explicit HunspellDict(const QString &lang, QString path);
-    ~HunspellDict();
+    ~HunspellDict() Q_DECL_OVERRIDE;
     bool isCorrect(const QString &word) const Q_DECL_OVERRIDE;
 
     QStringList suggest(const QString &word) const Q_DECL_OVERRIDE;
 
-    bool storeReplacement(const QString &bad,
-                                  const QString &good) Q_DECL_OVERRIDE;
+    bool storeReplacement(const QString &bad, const QString &good) Q_DECL_OVERRIDE;
 
     bool addToPersonal(const QString &word) Q_DECL_OVERRIDE;
     bool addToSession(const QString &word) Q_DECL_OVERRIDE;
@@ -50,8 +41,8 @@ public:
 private:
     QByteArray toDictEncoding(const QString &word) const;
 
-    Hunspell *m_speller;
-    QTextCodec *m_codec;
+    Hunspell *m_speller = nullptr;
+    QTextCodec *m_codec = nullptr;
 };
 
 #endif
